@@ -37,7 +37,6 @@
 #include <KMessageBox>
 
 // KShisen
-#include "debug.h"
 #include "prefs.h"
 
 namespace KShisen
@@ -55,7 +54,7 @@ Board::Board(QWidget * parent)
     , m_gameClock()
     , m_tiles()
     , m_background()
-    , m_random()
+    , m_random(QRandomGenerator::global()->generate())
     , m_undo()
     , m_redo()
     , m_markX(0)
@@ -85,7 +84,6 @@ Board::Board(QWidget * parent)
 {
     m_tileRemove1.setX(-1);
 
-    m_random.setSeed(0);
     resetTimer();
 
     QPalette palette;
@@ -394,7 +392,7 @@ void Board::setSize(int x, int y)
 
     resizeBoard();
     newGame();
-    emit changed();
+    Q_EMIT changed();
 }
 
 void Board::resizeEvent(QResizeEvent * e)
@@ -404,7 +402,7 @@ void Board::resizeEvent(QResizeEvent * e)
         qCDebug(KSHISEN_General) << "[resizeEvent] spontaneous";
     }
     resizeBoard();
-    emit resized();
+    Q_EMIT resized();
 }
 
 void Board::resizeBoard()
@@ -469,8 +467,8 @@ void Board::newGame()
     if (m_shuffle == 0) {
         update();
         resetTimer();
-        emit newGameStarted();
-        emit changed();
+        Q_EMIT newGameStarted();
+        Q_EMIT changed();
         return;
     }
 
@@ -478,8 +476,8 @@ void Board::newGame()
     auto const tx = xTiles();
     auto const ty = yTiles();
     for (decltype(tx * ty * m_shuffle) i = 0; i < tx * ty * m_shuffle; ++i) {
-        auto const tilePos1 = TilePos(m_random.getLong(tx), m_random.getLong(ty));
-        auto const tilePos2 = TilePos(m_random.getLong(tx), m_random.getLong(ty));
+        auto const tilePos1 = TilePos(m_random.bounded(tx), m_random.bounded(ty));
+        auto const tilePos2 = TilePos(m_random.bounded(tx), m_random.bounded(ty));
         // keep and use t, because the next setField() call changes what field() will return
         // so there would a significant impact on shuffling with the field() call put into the
         // place where 't' is used
@@ -492,8 +490,8 @@ void Board::newGame()
     if (!m_solvableFlag) {
         update();
         resetTimer();
-        emit newGameStarted();
-        emit changed();
+        Q_EMIT newGameStarted();
+        Q_EMIT changed();
         return;
     }
 
@@ -521,8 +519,8 @@ void Board::newGame()
         // redistribute unsolved tiles
         while (numberOfTiles > 0) {
             // get a random tile
-            auto const r1 = m_random.getLong(numberOfTiles);
-            auto const r2 = m_random.getLong(numberOfTiles);
+            auto const r1 = m_random.bounded(numberOfTiles);
+            auto const r2 = m_random.bounded(numberOfTiles);
             auto const tile = tiles.at(r1);
             auto const apos = pos.at(r2);
 
@@ -550,7 +548,7 @@ void Board::newGame()
 
     update();
     resetTimer();
-    emit changed();
+    Q_EMIT changed();
 }
 
 bool Board::tilesMatch(int tile1, int tile2) const
@@ -899,7 +897,7 @@ void Board::marked(TilePos tilePos)
             for (auto move : qAsConst(m_possibleMoves)) {
                 if (move.isInPath(tilePos)) {
                     performMove(move);
-                    emit selectATile();
+                    Q_EMIT selectATile();
                     return;
                 }
             }
@@ -919,7 +917,7 @@ void Board::marked(TilePos tilePos)
     if (tilePos.x() == m_markX && tilePos.y() == m_markY) { // the piece is already marked
         // unmark the piece
         unmarkTile();
-        emit selectATile();
+        Q_EMIT selectATile();
         return;
     }
 
@@ -929,7 +927,7 @@ void Board::marked(TilePos tilePos)
         drawPossibleMoves(false);
         m_possibleMoves.clear();
         repaintTile(tilePos);
-        emit selectAMatchingTile();
+        Q_EMIT selectAMatchingTile();
         return;
     }
     if (m_possibleMoves.size() > 1) { // if the click is on any of the current possible moves, make that move
@@ -937,7 +935,7 @@ void Board::marked(TilePos tilePos)
         for (auto move : qAsConst(m_possibleMoves)) {
             if (move.isInPath(tilePos)) {
                 performMove(move);
-                emit selectATile();
+                Q_EMIT selectATile();
                 return;
             }
         }
@@ -949,7 +947,7 @@ void Board::marked(TilePos tilePos)
     // both tiles do not match
     if (!tilesMatch(tile1, tile2)) {
         unmarkTile();
-        emit tilesDoNotMatch();
+        Q_EMIT tilesDoNotMatch();
         return;
     }
 
@@ -966,19 +964,19 @@ void Board::marked(TilePos tilePos)
             // if all moves have no slide, it doesn't matter
             if (withSlide > 0) {
                 drawPossibleMoves(true);
-                emit selectAMove();
+                Q_EMIT selectAMove();
                 return;
             }
         }
 
         // only one move possible, perform it
         performMove(m_possibleMoves.front());
-        emit selectATile();
+        Q_EMIT selectATile();
         // game is over?
         // Must delay until after tiles fall to make this test
         // See undrawConnection GP.
     } else {
-        emit invalidMove();
+        Q_EMIT invalidMove();
         m_connection.clear();
     }
 }
@@ -1328,7 +1326,7 @@ void Board::undrawConnection()
         applyGravity();
         m_tileRemove1.setX(-1);
         update();
-        emit tileCountChanged();
+        Q_EMIT tileCountChanged();
     }
 
     // is already undrawn?
@@ -1361,7 +1359,7 @@ void Board::undrawConnection()
     // game is over?
     if (!hint_I(dummyPossibleMoves)) {
         m_gameClock.pause();
-        emit endOfGame();
+        Q_EMIT endOfGame();
     }
     m_paintInProgress = false;
 }
@@ -1416,7 +1414,7 @@ void Board::madeMove(TilePos tilePos1, TilePos tilePos2, Slide slide)
     if (!m_redo.empty()) {
         m_redo.clear();
     }
-    emit changed();
+    Q_EMIT changed();
 }
 
 bool Board::canUndo() const
@@ -1636,7 +1634,7 @@ void Board::undo()
     repaintTile(TilePos(move->x2(), move->y2()));
 
     m_redo.push_front(std::move(move));
-    emit changed();
+    Q_EMIT changed();
 }
 
 void Board::redo()
@@ -1659,7 +1657,7 @@ void Board::redo()
         repaintTile(TilePos(move->x2(), move->y2()));
         applyGravity();
         m_undo.push_back(std::move(move));
-        emit changed();
+        Q_EMIT changed();
     }
 }
 
@@ -1861,7 +1859,7 @@ void Board::setPauseEnabled(bool enabled)
         m_gameState = GameState::Normal;
         m_gameClock.resume();
     }
-    emit changed();
+    Q_EMIT changed();
     update();
 }
 
@@ -1907,7 +1905,7 @@ void Board::setGameStuckEnabled(bool enabled)
         m_gameState = GameState::Normal;
         m_gameClock.resume();
     }
-    emit changed();
+    Q_EMIT changed();
     update();
 }
 
@@ -1917,7 +1915,7 @@ void Board::setGameOverEnabled(bool enabled)
         return;
     }
     m_gameState = GameState::Over;
-    emit changed();
+    Q_EMIT changed();
     update();
 }
 
@@ -1927,7 +1925,7 @@ void Board::setCheatModeEnabled(bool enabled)
         return;
     }
     m_cheat = enabled;
-    emit cheatStatusChanged();
+    Q_EMIT cheatStatusChanged();
 }
 
 bool Board::isOver() const
