@@ -32,9 +32,7 @@
 #include <QList>
 #include <QSize>
 #include <QWidget>
-
-// KDE
-#include <KRandomSequence>
+#include <QRandomGenerator>
 
 // KDEGames
 #include <KGameClock>
@@ -153,7 +151,7 @@ public:
     */
     bool hasCheated() const;
 
-signals:
+Q_SIGNALS:
     void markMatched(); // unused?
     void newGameStarted();
     void changed();
@@ -167,7 +165,7 @@ signals:
     void selectAMatchingTile();
     void cheatStatusChanged();
 
-public slots:
+public Q_SLOTS:
     /** Does most of the newGame work.
      * This slot is called from the KShisen::invokeNewGame() signal from KShisen and
      * should call KShisen::newGame again to do the work that cannot be done
@@ -189,7 +187,7 @@ public slots:
     /// Loads the given background
     bool loadBackground(QString const & pathToBackground);
 
-private slots:
+private Q_SLOTS:
     void undrawConnection();
 
 protected:
@@ -304,7 +302,7 @@ private:
     KMahjonggTileset m_tiles;
     KMahjonggBackground m_background;
 
-    KRandomSequence m_random;
+    QRandomGenerator m_random;
 
     std::list<std::unique_ptr<Move>> m_undo; ///< Undo history
     std::list<std::unique_ptr<Move>> m_redo; ///< Redo history
