@@ -35,8 +35,7 @@
 // KShisen
 #include "app.h"
 #include "debug.h"
-
-static constexpr char description[] = I18N_NOOP("A KDE game similar to Mahjongg");
+#include "kshisen_version.h"
 
 int main(int argc, char ** argv)
 {
@@ -52,8 +51,11 @@ int main(int argc, char ** argv)
 
     KLocalizedString::setApplicationDomain("kshisen");
 
-    KAboutData aboutData(QStringLiteral("kshisen"), i18n("Shisen-Sho"), QStringLiteral("1.10+ #25"),
-                         i18n(description), KAboutLicense::GPL, i18n("Copyright 1997 Mario Weilguni"));
+    KAboutData aboutData(QStringLiteral("kshisen"), i18n("Shisen-Sho"),
+                         QStringLiteral(KSHISEN_VERSION_STRING),
+                         i18n("A game similar to Mahjongg"),
+                         KAboutLicense::GPL,
+                         i18n("Copyright 1997 Mario Weilguni"));
     aboutData.setHomepage(QStringLiteral("https://kde.org/applications/games/org.kde.kshisen"));
     aboutData.addAuthor(i18n("Frederik Schwarzer"), i18n("Current Maintainer"), QStringLiteral("schwarzer@kde.org"));
     aboutData.addAuthor(i18n("Dave Corrie"), i18n("Former Maintainer"), QStringLiteral("kde@davecorrie.com"));
